@@ -1,8 +1,9 @@
 func.calcXSquare <-
-function(yiCalc, yi, yMean){
-#  return xsquare <-
+function( yiCalc, yi, yMean ){
+  return( 
     1 -
     sum( (yiCalc - yi) * (yiCalc - yi)) /
     sum( (yi - yMean) * (yi - yMean) )
+  )
 }
 
